@@ -116,7 +116,11 @@ class AutoCrosswalk(object):
                 W[key_name] = 0
             
         return W    
-        
+
+    def __fix_mask_as_list(self, M):
+        if isinstance(M,bool):
+            M = [M]
+        return M        
     # -------------------------------------------------------------------------
     # Private functions
     # -------------------------------------------------------------------------
@@ -319,7 +323,7 @@ class AutoCrosswalk(object):
             P /= len(keys)
         
         return P
-    
+        
     def _compute_context_transition_prob(self,keys,transition_matrix):
         """
         Estimate transition probability matrix from context key
@@ -361,12 +365,17 @@ class AutoCrosswalk(object):
                 # Get similarities                
                 similarities = self.contextmatcher.compute_similarity(a=key_from, b=key_to, metric="cosine")
 
-                # Replace entries in probability matrix            
-                P_temp.loc[bg.tools.isin(a=P_temp.index.get_level_values(level=key),
-                                         b=key_from),
-                           bg.tools.isin(a=P_temp.columns.get_level_values(level=key),
+                # Masks (must be list)
+                mask_idx = bg.tools.isin(a=P_temp.index.get_level_values(level=key),
+                                         b=key_from)
+                mask_idx = self.__fix_mask_as_list(M=mask_idx)
+        
+                mask_col = bg.tools.isin(a=P_temp.columns.get_level_values(level=key),
                                          b=key_to)
-                           ] = similarities.values
+                mask_col = self.__fix_mask_as_list(M=mask_col)
+
+                # Replace entries in probability matrix            
+                P_temp.loc[mask_idx,mask_col] = similarities.values
 
                 # Sanity check
                 if ((P_temp>1).any() | (P_temp<0).any()).any():
@@ -438,13 +447,13 @@ class AutoCrosswalk(object):
         transition_matrix_text = self._reindex_df(df=transition_matrix_text,
                                                   index=transition_matrix_null.index,
                                                   columns=transition_matrix_null.columns)
-            
+
+        # Check if each key has an exact match (either numeric or text). We only compute context similarity if no exact match is available
+        has_exact_numeric_text_match = (transition_matrix_numeric==1).sum(axis=1) + (transition_matrix_text==1).sum(axis=1)            
+        
         # ---------------------------------------------------------------------
         # CONTEXT transition probability matrix
         # ---------------------------------------------------------------------
-        # Check if each key has an exact match (either numeric or text). We only compute context similarity if no exact match is available
-        has_exact_numeric_text_match = (transition_matrix_numeric==1).sum(axis=1) + (transition_matrix_text==1).sum(axis=1)
-        
         if has_exact_numeric_text_match.all():
             # All keys have exact match. Thus, copy another transition matrix and fill with 1
             transition_matrix_context = transition_matrix_null.copy()
@@ -631,8 +640,7 @@ class AutoCrosswalk(object):
                 self.has_all_keys = True
             else:
                 self.has_all_keys = False
-                
-
+            
             if not self.has_all_keys:
                 
                 if self.verbose:
